==> haskell-unexceptionalio-0.5.1-9-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-unexceptionalio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unexceptionalio
version:              0.5.1
visibility:           public
id:                   unexceptionalio-0.5.1-GcYY4WOTCYcHCcS95HuZ7
key:                  unexceptionalio-0.5.1-GcYY4WOTCYcHCcS95HuZ7
license:              LicenseRef-OtherLicense
copyright:            © 2013-2018 Stephen Paul Weber
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               Stephen Paul Weber <singpolyma@singpolyma.net>
stability:            experimental
homepage:             https://github.com/singpolyma/unexceptionalio
synopsis:             IO without any non-error, synchronous exceptions
description:
    When you'\''ve caught all the exceptions that can be handled safely,
    this is what you'\''re left with.

    It is intended that you use qualified imports with this library.

    > import UnexceptionalIO (UIO)
    > import qualified UnexceptionalIO as UIO

    You may also wish to investigate unexceptionalio-trans if you like
    monad transformers.

    Blog post: http://sngpl.ma/p4uT0

category:             Control
abi:                  b8dac9fdd62e1b8ad0189fa353046b5f
exposed:              True
exposed-modules:      UnexceptionalIO
import-dirs:          /usr/lib/ghc-9.2.8/site-local/unexceptionalio-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unexceptionalio-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unexceptionalio
hs-libraries:         HSunexceptionalio-0.5.1-GcYY4WOTCYcHCcS95HuZ7
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-unexceptionalio/html/unexceptionalio.haddock

haddock-html:         /usr/share/doc/haskell-unexceptionalio/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unexceptionalio-0.5.1-10-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-unexceptionalio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unexceptionalio
version:              0.5.1
visibility:           public
id:                   unexceptionalio-0.5.1-CUq11cWwrfNKf4bgrFFKJq
key:                  unexceptionalio-0.5.1-CUq11cWwrfNKf4bgrFFKJq
license:              LicenseRef-OtherLicense
copyright:            © 2013-2018 Stephen Paul Weber
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               Stephen Paul Weber <singpolyma@singpolyma.net>
stability:            experimental
homepage:             https://github.com/singpolyma/unexceptionalio
synopsis:             IO without any non-error, synchronous exceptions
description:
    When you'\''ve caught all the exceptions that can be handled safely,
    this is what you'\''re left with.

    It is intended that you use qualified imports with this library.

    > import UnexceptionalIO (UIO)
    > import qualified UnexceptionalIO as UIO

    You may also wish to investigate unexceptionalio-trans if you like
    monad transformers.

    Blog post: http://sngpl.ma/p4uT0

category:             Control
abi:                  c8c2f190287a7a0736a1230f1a49aff8
exposed:              True
exposed-modules:      UnexceptionalIO
import-dirs:          /usr/lib/ghc-9.4.8/site-local/unexceptionalio-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unexceptionalio-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unexceptionalio-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unexceptionalio
hs-libraries:         HSunexceptionalio-0.5.1-CUq11cWwrfNKf4bgrFFKJq
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-unexceptionalio/html/unexceptionalio.haddock

haddock-html:         /usr/share/doc/haskell-unexceptionalio/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
